@@ -17,7 +17,7 @@ def save_step(
     run_config = RunConfiguration()
     run_config.target = compute_target
     run_config.environment = environment
-    print("Run configuration created for the images saving step")
+    print("Run configuration created for the data saving step")
 
     step = PythonScriptStep(
         script_name="save.py",
